LineThumbShape class

A variant of the default circle thumb shape Similar to the one found in Android 13 Media control

Constructors

LineThumbShape({Size thumbSize = const Size(8, 32)})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbSize → Size
The size of the thumb
final

Methods

getPreferredSize(bool isEnabled, bool isDiscrete) → Size
Returns the preferred size of the shape, based on the given conditions.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
paint(PaintingContext context, Offset center, {required Animation<double> activationAnimation, required Animation<double> enableAnimation, required bool isDiscrete, required TextPainter labelPainter, required RenderBox parentBox, required SliderThemeData sliderTheme, required TextDirection textDirection, required double value, required double textScaleFactor, required Size sizeWithOverflow}) → void
Paints the shape, taking into account the state passed to it.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited