activeColor property
The color to use for the portion of the slider track that is active.
The "active" side of the slider is the side between the thumb and the minimum value.
If null, SliderThemeData.activeTrackColor of the ambient
SliderTheme is used. If that is null, ColorScheme.primary of the
surrounding ThemeData is used.
Using a SliderTheme gives much more fine-grained control over the
appearance of various components of the slider.
Implementation
final Color? activeColor;