allowedInteraction property
SliderInteraction?
allowedInteraction
finalinherited
Allowed way for the user to interact with the Slider.
For example, if this is set to SliderInteraction.tapOnly, the user can
interact with the slider only by tapping anywhere on the track. Sliding
will have no effect.
Defaults to SliderInteraction.tapAndSlide.
Implementation
final SliderInteraction? allowedInteraction;