overlayColor property
The highlight color that's typically used to indicate that the slider thumb is focused, hovered, or dragged.
If this property is null, Slider will use activeColor with
an opacity of 0.12, If null, SliderThemeData.overlayColor
will be used.
If that is also null, If ThemeData.useMaterial3 is true,
Slider will use ColorScheme.primary with an opacity of 0.08 when
slider thumb is hovered and with an opacity of 0.1 when slider thumb
is focused or dragged, If ThemeData.useMaterial3 is false, defaults
to ColorScheme.primary with an opacity of 0.12.
Implementation
final WidgetStateProperty<Color?>? overlayColor;