padding property
Determines the padding around the Slider.
If specified, this padding overrides the default vertical padding of
the Slider, defaults to the height of the overlay shape, and the
horizontal padding, defaults to the width of the thumb shape or
overlay shape, whichever is larger.
Implementation
final EdgeInsetsGeometry? padding;